==> core-components-file-upload-item-6.2.1.tgz: package/esm/components/status-control/components/status-control-icon/status-control-icon.js <==
import React, { useContext } from 'react';
import cn from 'classnames';
import { Document1CMIcon } from '@alfalab/icons-glyph/Document1CMIcon';
import { DocumentDocMIcon } from '@alfalab/icons-glyph/DocumentDocMIcon';
import { DocumentExcelMIcon } from '@alfalab/icons-glyph/DocumentExcelMIcon';
import { DocumentImageMIcon } from '@alfalab/icons-glyph/DocumentImageMIcon';
import { DocumentMIcon } from '@alfalab/icons-glyph/DocumentMIcon';
import DocumentOffMIcon from '@alfalab/icons-glyph/DocumentOffMIcon';
import { DocumentPdfMIcon } from '@alfalab/icons-glyph/DocumentPdfMIcon';
import { PaperclipMIcon } from '@alfalab/icons-glyph/PaperclipMIcon';
import { FileUploadItemContext } from '../../../../context/file-upload-item-context.js';
import { isInitialStatus, getExtension } from '../../../../utils.js';

var styles = {"iconPDFColored":"file-upload-item__iconPDFColored_118to","iconDOCColored":"file-upload-item__iconDOCColored_118to","iconExcelColored":"file-upload-item__iconExcelColored_118to","icon1CColored":"file-upload-item__icon1CColored_118to","iconDocumentColored":"file-upload-item__iconDocumentColored_118to"};
require('./status-control-icon.css')

/* eslint-disable complexity */
var StatusControlIcon = function () {
    var _a, _b, _c, _d, _e;
    var _f = useContext(FileUploadItemContext), _g = _f.title, title = _g === void 0 ? '' : _g, uploadStatus = _f.uploadStatus, iconStyle = _f.iconStyle, CustomIcon = _f.customIcon, imageUrl = _f.imageUrl, showRestore = _f.showRestore;
    if (imageUrl) {
        return null;
    }
    if (CustomIcon) {
        return React.createElement(CustomIcon, null);
    }
    if (isInitialStatus(uploadStatus)) {
        return React.createElement(PaperclipMIcon, null);
    }
    if (showRestore) {
        return React.createElement(DocumentOffMIcon, null);
    }
    var isColoredIcon = iconStyle === 'colored';
    var fileType = getExtension(title);
    switch (fileType) {
        case 'pdf':
        case 'ppt':
        case 'pptx':
            return React.createElement(DocumentPdfMIcon, { className: cn((_a = {}, _a[styles.iconPDFColored] = isColoredIcon, _a)) });
        case 'doc':
        case 'docx':
            return React.createElement(DocumentDocMIcon, { className: cn((_b = {}, _b[styles.iconDOCColored] = isColoredIcon, _b)) });
        case 'xls':
        case 'xlsx':
            return (React.createElement(DocumentExcelMIcon, { className: cn((_c = {}, _c[styles.iconExcelColored] = isColoredIcon, _c)) }));
        case '1c':
            return React.createElement(Document1CMIcon, { className: cn((_d = {}, _d[styles.icon1CColored] = isColoredIcon, _d)) });
        case 'png':
        case 'jpg':
        case 'jpeg':
        case 'svg':
        case 'tif':
        case 'tiff':
            return React.createElement(DocumentImageMIcon, null);
        default:
            return (React.createElement(DocumentMIcon, { className: cn((_e = {}, _e[styles.iconDocumentColored] = isColoredIcon, _e)) }));
    }
};

export { StatusControlIcon };

==> core-components-file-upload-item-6.2.2.tgz: package/esm/components/status-control/components/status-control-icon/status-control-icon.js <==
import React, { useContext } from 'react';
import cn from 'classnames';
import { Document1CMIcon } from '@alfalab/icons-glyph/Document1CMIcon';
import { DocumentDocMIcon } from '@alfalab/icons-glyph/DocumentDocMIcon';
import { DocumentExcelMIcon } from '@alfalab/icons-glyph/DocumentExcelMIcon';
import { DocumentImageMIcon } from '@alfalab/icons-glyph/DocumentImageMIcon';
import { DocumentMIcon } from '@alfalab/icons-glyph/DocumentMIcon';
import DocumentOffMIcon from '@alfalab/icons-glyph/DocumentOffMIcon';
import { DocumentPdfMIcon } from '@alfalab/icons-glyph/DocumentPdfMIcon';
import { PaperclipMIcon } from '@alfalab/icons-glyph/PaperclipMIcon';
import { FileUploadItemContext } from '../../../../context/file-upload-item-context.js';
import { isInitialStatus, getExtension } from '../../../../utils.js';

var styles = {"iconPDFColored":"file-upload-item__iconPDFColored_neps1","iconDOCColored":"file-upload-item__iconDOCColored_neps1","iconExcelColored":"file-upload-item__iconExcelColored_neps1","icon1CColored":"file-upload-item__icon1CColored_neps1","iconDocumentColored":"file-upload-item__iconDocumentColored_neps1"};
require('./status-control-icon.css')

/* eslint-disable complexity */
var StatusControlIcon = function () {
    var _a, _b, _c, _d, _e;
    var _f = useContext(FileUploadItemContext), _g = _f.title, title = _g === void 0 ? '' : _g, uploadStatus = _f.uploadStatus, iconStyle = _f.iconStyle, CustomIcon = _f.customIcon, imageUrl = _f.imageUrl, showRestore = _f.showRestore;
    if (imageUrl) {
        return null;
    }
    if (CustomIcon) {
        return React.createElement(CustomIcon, null);
    }
    if (isInitialStatus(uploadStatus)) {
        return React.createElement(PaperclipMIcon, null);
    }
    if (showRestore) {
        return React.createElement(DocumentOffMIcon, null);
    }
    var isColoredIcon = iconStyle === 'colored';
    var fileType = getExtension(title);
    switch (fileType) {
        case 'pdf':
        case 'ppt':
        case 'pptx':
            return React.createElement(DocumentPdfMIcon, { className: cn((_a = {}, _a[styles.iconPDFColored] = isColoredIcon, _a)) });
        case 'doc':
        case 'docx':
            return React.createElement(DocumentDocMIcon, { className: cn((_b = {}, _b[styles.iconDOCColored] = isColoredIcon, _b)) });
        case 'xls':
        case 'xlsx':
            return (React.createElement(DocumentExcelMIcon, { className: cn((_c = {}, _c[styles.iconExcelColored] = isColoredIcon, _c)) }));
        case '1c':
            return React.createElement(Document1CMIcon, { className: cn((_d = {}, _d[styles.icon1CColored] = isColoredIcon, _d)) });
        case 'png':
        case 'jpg':
        case 'jpeg':
        case 'svg':
        case 'tif':
        case 'tiff':
            return React.createElement(DocumentImageMIcon, null);
        default:
            return (React.createElement(DocumentMIcon, { className: cn((_e = {}, _e[styles.iconDocumentColored] = isColoredIcon, _e)) }));
    }
};

export { StatusControlIcon };
